@@ -1,30 +1,30 @@
 """
 ################################################################################
-asciiporn is designed for interactive graphics viewing within an ssh terminal,
+asciiporn is designed for interactive graphics viewing within an ssh terminal
 by converting graphics into colorized ascii-art. asciiporn has 256 color support
-& contains integrated c code for efficent graphics rendering.
-asciiporn can easily render 32bit megapixel graphics on a 1ghz 500mb machine
+& is partially written in c for efficent graphics rendering.
+asciiporn can easily render 24bit megapixel graphics on a 1ghz 500mb machine
 
 screenshots of both plotting and image viewing r included w/ this distribution.
 asciiporn is hard-coded to use lucida-console font, but courier font will work
-as well.  the screenshots show putty ssh w/ lucida-console 5pt.
+as well. the screenshots show putty ssh w/ lucida-console 5pt.
 
 how to enable 256 color in putty:  http://www.emacswiki.org/emacs/PuTTY#toc2
 how to enable 256 color in xterm:  http://www.frexx.de/xterm-256-notes/
 how to enable 256 color in screen: http://www.frexx.de/xterm-256-notes/
 
-for basic usage, remotely run python in an ssh terminal:
+for quick example usage, remotely run python in an ssh terminal:
 
-  >>> ## print image file as colorized ascii art
+  >>> ## print image file as colorized ascii art in ssh terminal
   >>> from asciiporn import img2txt
   >>> print img2txt("mario.jpg")
 
-  >>> ## plot several math functions
+  >>> ## plot several math functions in ssh terminal
   >>> from asciiporn import plot
   >>> from math import cos, sin, pi
   >>> print plot(ft = [cos, sin], tmin = 0.0, tmax = 2*pi)
 
-  >>> ## plot 3d function
+  >>> ## plot 3d function in ssh terminal
   >>> from asciiporn import plot3d
   >>> from math import sin, pi
   >>> print plot3d(
@@ -64,9 +64,9 @@ INSTALL:
 ################################################################################
 PLOT USAGE:
 
-2d plots take 2 main arguments:
-  y - a list of functions to plot
-  trange - t domain
+2d plots take 3 main arguments:
+  ft - a list of functions to plot
+  tmin, tmax - t domain
 
   >>> import asciiporn, numpy
   >>> asciiporn.plot(
@@ -107,8 +107,8 @@ l?*~_-----_>cC}lTl{7Tx_--------------------------------------------_+*Tll'*+_---
 
 
 
-3d plots have an extra argument:
-  zrange - z domain
+3d plots have 2 extra arguments:
+  zmin, zmax - z domain
 
   >>> import asciiporn, numpy
   >>> asciiporn.plot3d(
@@ -219,7 +219,7 @@ to 0.5 (or less):
 
   ... beautiful color image appears ^_-
 
-  >>> plaintxt = asciiporn.img2plaintxt("mario.jpg", scale = 0.75)
+  >>> plaintxt = asciiporn.img2plaintxt("mario.jpg", scale = 0.5)
   >>> print( plaintxt )
 
   ... rather plain b/w img -_-, but u can copy & paste in documents ...
@@ -322,7 +322,7 @@ RECENT CHANGELOG:
   rewrote 3d plotter
   fixed more 64bit issues
 20081123
-  fixed bug where 64bit  gets truncated to 32 on 32bit machine
+  fixed bug where 64bit gets truncated to 32 on 32bit machine
   256 color support
 20081119
   fixed bugs in setup.py
@@ -335,23 +335,23 @@ if sys.version_info[1] < 6: raise Exception("asciiporn requires Python 2.6 or hi
 
 
 
-__author__ =	"kai zhu"
-__author_email__ =	"kaizhu@ugcs.caltech.edu"
-__description__ =	"""
-view color images & scientific plots from ssh terminal
+__author__ = "kai zhu"
+__author_email__ = "kaizhu@ugcs.caltech.edu"
+__description__ = """
+view color images & scientific plots in ssh terminal
 (screenshots using putty ssh terminal included)
 """
-__download_url__ =	None
-__keywords__ =	None
-__license__ =	"BSD"
-__maintainer__ =	None
-__maintainer_email__ =	None
-__obsoletes__ =	None
-__platforms__ =	None
-__provides__ =	None
-__requires__ =	["PIL", "numpy"]
+__download_url__ = None
+__keywords__ = None
+__license__ = "GPL"
+__maintainer__ = None
+__maintainer_email__ = None
+__obsoletes__ = None
+__platforms__ = None
+__provides__ = None
+__requires__ = ["PIL", "numpy"]
 __url__ = "http://pypi.python.org/pypi/asciiporn"
-__version__  = "2009.01.24"
+__version__ = "2009.01.25"
 ## end setup info
 
 
@@ -394,7 +394,7 @@ class parser(ast.NodeTransformer):
 
 
 import imp ## import hook
-class importer(object):
+class _importer(object):
   py3k_syntax = None ## identifier
   magic = "\nfrom __future__ import py3k_syntax\n"
 
@@ -418,7 +418,7 @@ class importer(object):
 
     s = "\n" + file.read() + "\n"; file.close()
     if self.magic not in s: return ## no py3k_syntax magic found in file
-    s = s.replace(self.magic, "\nfrom __future__ import with_statement, division, print_function; from py3k_syntax import *\n", 1)
+    s = s.replace(self.magic, "\nfrom __future__ import with_statement, division, print_function; from asciiporn import *\n", 1)
     s = s[1:-1] ## preserve lineno (for debugging)
 
     self.found = s, fpath, desc, tp; return self
@@ -438,7 +438,7 @@ class importer(object):
       if new: del sys.modules[mname] ## if new module fails loading, del from sys.modules
       print( "\nFAILED py3k_syntax load_module(mname = %s, fpath = %s, desc = %s)\n" % (mname, fpath, desc) ) ## notify user exception originated from failed py3k_syntax import
       raise
-importer()
+importer = _importer()
 
 
 
@@ -451,10 +451,14 @@ if 1: ## builtins
   zip = itertools.izip
   zip_longest = itertools.izip_longest
   def oct(x): return builtins.oct(x).replace("0", "0o", 1)
+  def reload(m):
+    try:
+      if not importer.find_module(m.__name__, path = [os.path.dirname(m.__file__)]): raise ImportError
+    except: return builtins.reload(m)
+    return importer.load_module(m.__name__)
 
 
 
-m = sys.modules.get("asciiporn._asciiporn")
-if m: _asciiporn = reload(m)
-else: import _asciiporn
-from _asciiporn import *
+# importer.find_module("_asciiporn", path = __path__); _asciiporn = importer.load_module("_asciiporn")
+if "_asciiporn" in globals(): reload(_asciiporn)
+import _asciiporn; from _asciiporn import *; from _asciiporn import _asarray
